@@ -171,7 +171,7 @@ class Form(object):
                 prefix=self._prefix,
                 name=name.lower()
             )
-            
+
             formset = sclass(
                 form_class=formset._form_class,
                 data=data,
@@ -308,10 +308,7 @@ class Form(object):
         db = self._model.db
         data = dict([
             (key, val) for key, val in self.cleaned_data.items()
-            if (
-                (not isinstance(getattr(self, key), FormSet)) and
-                (getattr(self, key) is not None)
-            )
+            if not isinstance(getattr(self, key), FormSet)
         ])
         if self._backref and backref_obj:
             data[self._backref] = backref_obj
@@ -329,8 +326,7 @@ class Form(object):
         for key in self.changed_fields:
             if key in self.cleaned_data:
                 val = self.cleaned_data.get(key)
-                if val is not None:
-                    set_obj_value(obj, key, val)
+                set_obj_value(obj, key, val)
         return obj
 
     def __repr__(self):
